import java.util.*;

/**
 * Fenboard
 * Holds a chessboard, interact by FEN or a 64 matrix
 * may mask a board with another, print a board etc
 */

class fenboard {
    int[] itsBoard;
    String itsFen;

    public fenboard(){
	itsBoard = new int[64];
	for(int i=0;i<64;i++)
	    itsBoard[i]='.';
	itsFen="";
    }

    public fenboard(String fen){ setBoard(fen); }
    public fenboard(int[] board) { setBoard(board); }

    public boolean setBoard(String fen){
	if(!validateFen(fen))
	    return false;

	itsBoard=fen2board(fen);
	itsFen=fen;
	return true;
    }

    public int getPieceAt(int x, int y){
	if(x<0 || x>7 || y<0 || y>7) return 0;

	return itsBoard[y*8+x];
    }

    public boolean setBoard(int[] board){
	if(board.length != 64)
	    return false;

	itsBoard=board;
	return true;
    }

    public void print(){
	printBoard(itsBoard);
    }

    public int[] getBoard() { return itsBoard; }


    public fenboard mask(fenboard b){
	fenboard output;
	output=new fenboard(mask(getBoard(),b.getBoard()));
	return output;
    }

    public int diffCount(fenboard b){
	fenboard m = mask(b);
	int[] table=m.getBoard();
	int output=0;
	for(int i=0;i<64;i++){
	    if(table[i]!='.')
		output++;
	}

	return output;
    }




      /**
       * Returns a 64-array of a given fen
       *
       */
      int[] fen2board(String aFen){
          int[] board = new int[64];
          int square=0;
          int chr=0;

          while(square<64){
              char c = aFen.charAt(chr);
              if(c=='r'||c=='R'||c=='n'||c=='N'||c=='b'||c=='B'||c=='q'||c=='Q'||c=='k'||c=='K'||c=='p'||c=='P'){
                  board[square]=c;
                  square++;
              }
              if(c>='1' && c<='8'){
                  for(int i=0;i<c-'1'+1;i++){
                      board[square]='.';
                      square++;
                  }
              }
              chr++;
          }
          return board;
      }


      /**
       * Prints a nice board
       */
      String[] outputBoard(int[] board){
	  String s="";
	  String[] out = new String[8];
          for(int chr=0;chr<64;chr++){
              if(board[chr]<0)
                  s += "-" + (char)(Math.abs(board[chr]));
              else if(board[chr]==0)
                  s += ", ";
              else
                  s += (char)board[chr] + " ";
              if((chr+1)%8==0){
                  out[chr/8]=s;
		  s="";
	      }
          }

	  return out;
      }

      void printBoard(int[] board){
	  String[] out = outputBoard(board);
	  for(int i=0;i<8;i++){
	      System.out.println(out[i]);
	  }
	  System.out.println();
      }


      int[] mask(int[] b1, int[] b2){
          int[] output=new int[64];
          for(int i=0;i<64;i++){
              if(b2[i]!=b1[i]){
                  if(b2[i]=='.')
                      output[i]=-b1[i];
                  else
                      output[i]=b2[i];
              }
              else
                  output[i] = '.';//b2[i]-b1[i];
          }
          return output;
      }



      /**
       * Check if given FEN is valid
       */
      boolean validateFen(String aFen){
           /* Only check board part of FEN */
	   if(aFen.indexOf(' ')>0){
	     aFen = aFen.substring(0,aFen.indexOf(' '));
	   }

           /* FEN contains 7 '/' */
           int s=0;
           for(int c=0;c<aFen.length();c++){
	     if(aFen.charAt(c) == '/') s++;
	   }
	   if(s!=7) return false;

	   /* FEN has 8 empty squares/pieces per row */
           int x=0;
           for(int c=0;c<aFen.length();c++){
	     if(aFen.charAt(c) == '/'){
	       if(x!=8) return false;
	       else x=0;
	     }
	     else
	     {
		if(aFen.charAt(c) >= '1' && aFen.charAt(c)<= '8')
		  x+= aFen.charAt(c)-'1' ;
		x++;
	     }
	   }
           if(x!=8) return false;

	   return true;
      }


}
