
/*
 *  TT-CHESS
 *  More information is available at http://www.chesstech.net/~ttchess
 *  Copyright (C) 2003 Jonas Forsslund (jofo02@kth.se)
 *  All rights reserved.
 *
 *  TT-CHESS is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  TT-CHESS is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with TT-CHESS; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */



/*

TTChess - a chessboard scanner for DGT chess boards

Version 20031020

This program detects multiple DGT chess boards connected to the serial port,
and writes html-files with the history and current status of each board.
Every 10 seconds or so a rescan for new or removed boards is made.
Active boards are read once each second and if a change has occurred
then that board's html-files are updated. The boards themselves have
a small memory, so the timing is not critical and no moves should ever
be missed.

This program is tested with Sun Java 1.4.1 and Java Communications API 2.0.
The Communications API is a Java Standard Extension and is not a part of
the core JDK. It must be downloaded from Sun and installed separately.

*/


//import java.io.*;
//import java.util.*;
//import javax.comm.*;

public class ttchess implements Runnable {

	static boolean debug = false;  // If true every send/received byte will be written to the screen
	String comport = "COM1";

	public static void main(String[] args) {
		ttchess t;

		if(args.length > 0)
		  t = new ttchess(args[0]);
                else
		  t = new ttchess();
	}

	public ttchess() {
		(new Thread(this)).start();
	}

	public ttchess(String comport) {
		this.comport = comport;
		(new Thread(this)).start();
	}

	// Destructor
	public void finalize()
	{
		ttchess_mysql.disconnect();
	}

	// This is the main loop. It samples all boards and tries at regular intervals
	// to find new boards and to mark non-answering boards as, well, non-answering.
	public void run() {
		ttchess_controller c = new ttchess_controller();
		if (c.connect(comport) == false) return;

System.out.println(ttchess_mysql.connect());

		int i = 0;
		while (true) {

			if ((i==0) || (c.db.count_alive()==0)) {
				while (c.find_all_boards()==0) {} // repeat until at least 1 board is alive
				c.dump_all_active_boards();
				i = 15;  // Do a board scan every 15 polls
			} else {
				try {Thread.sleep(1000);} catch(Throwable t) {}   // Wait between polls
			}
			c.poll_all_active_boards();
			i = i-1;
		}
	}


}

