// Class with constants and some useful functions.
// Other classes inherits from this.
class ttchess_common {

	// Commands from pc to board, bus mode
	static int DGT_TO_BUSMODE               = 0x4a;
	static int DGT_BUS_SEND_CLK             = 0x01 | 0x80;
	static int DGT_BUS_SEND_BRD             = 0x02 | 0x80;
	static int DGT_BUS_SEND_CHANGES         = 0x03 | 0x80;
	static int DGT_BUS_REPEAT_CHANGES       = 0x04 | 0x80;
	static int DGT_BUS_SET_START_GAME       = 0x05 | 0x80;
	static int DGT_BUS_SEND_FROM_START      = 0x06 | 0x80;
	static int DGT_BUS_PING                 = 0x07 | 0x80;
	static int DGT_BUS_END_BUSMODE          = 0x08 | 0x80;
	static int DGT_BUS_RESET                = 0x09 | 0x80;
	static int DGT_BUS_IGNORE_NEXT_BUS_PING = 0x0a | 0x80;
	static int DGT_BUS_SEND_VERSION         = 0x0b | 0x80;

	// Messages from board to pc, bus mode
	static int DGT_BUS_BRD_DUMP           = 0x03 | 0x80;
	static int DGT_BUS_BWTIME             = 0x04 | 0x80;
	static int DGT_BUS_UPDATE             = 0x05 | 0x80;
	static int DGT_BUS_FROM_START         = 0x06 | 0x80;
//	static int DGT_BUS_PING               = 0x07 | 0x80;
	static int DGT_BUS_START_GAME_WRITTEN = 0x08 | 0x80;
	static int DGT_BUS_VERSION            = 0x09 | 0x80;

	static boolean is_busmessage(int m) {
		return (m== DGT_BUS_BRD_DUMP || m == DGT_BUS_BWTIME ||
				m == DGT_BUS_UPDATE || m == DGT_BUS_FROM_START || m == DGT_BUS_PING ||
				m == DGT_BUS_START_GAME_WRITTEN || m == DGT_BUS_VERSION);
	}

	// Chess pieces
	static final int EMPTY   = 0x00;
	static final int WPAWN   = 0x01;
	static final int WROOK   = 0x02;
	static final int WKNIGHT = 0x03;
	static final int WBISHOP = 0x04;
	static final int WKING   = 0x05;
	static final int WQUEEN  = 0x06;
	static final int BPAWN   = 0x07;
	static final int BROOK   = 0x08;
	static final int BKNIGHT = 0x09;
	static final int BBISHOP = 0x0a;
	static final int BKING   = 0x0b;
	static final int BQUEEN  = 0x0c;

	boolean is_piece(int p) {
		return (p==EMPTY || p==WPAWN || p==WROOK ||
			 p==WKNIGHT || p==WBISHOP || p==WKING ||
			 p==WQUEEN || p==BPAWN || p==BROOK ||
			 p==BKNIGHT || p==BBISHOP || p==BKING ||
			 p==BQUEEN);
	}

	// EEPROM message codes
	static int EE_POWERUP         = 0x6a;
	static int EE_EOF             = 0x6b;
	static int EE_FOURROWS        = 0x6c;
	static int EE_EMPTYBOARD      = 0x6d;
	static int EE_DOWNLOADED      = 0x6e;
	static int EE_BEGINPOS        = 0x6f;
	static int EE_BEGINPOS_ROT    = 0x7a;
	static int EE_START_TAG       = 0x7b;
	static int EE_WATCHDOG_ACTION = 0x7c;
	static int EE_NOP             = 0x7f;
}
